<?php
  include("stilos/config.inc.php");
  include("../clases/BDConexion.php");
  include("../clases/clsEpp.php");
  include("funcion/funciones.php");
  include("Funciones.php");
  session_start();
  $objPer = new clsEpp;
  
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
<title><MMString:LoadString id="insertbar/formsHidden" /></title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<link href="style.css" rel="stylesheet" type="text/css">

<link href="Estilos.css" rel="stylesheet" type="text/css">

<link href="stilos/Estilos.css" rel="stylesheet" type="text/css">
<SCRIPT language=JavaScript src="js/calendario.js"></SCRIPT>
<!-- Copyright 2000,2001 Macromedia, Inc. All rights reserved. -->
<script language="JavaScript"> 
<!--
function print_1(sURL,x,y) {
if (!window.focus) return;
			var par;
			par = "width=" +x + ",height="+y+","
			par = par + "dependent=no,scrollbars=yes,resizable=yes,"
			par = par + "menubar=no,toolbar=no,status=no"
			var ventana = window.open(sURL,"Ver",par)
			ventana.focus();
}

function volver(){
  window.location="fondo.php";
          }
function NuevoTipoEqui(){
    window.location="cvp_nuevo_tipo_equi.php";
         }

//--> 
</script>
<script language="javascript" type="text/javascript">
function EnviarcodPer(){
	var codper = document.form1.var_persona.value;
	window.location="cvp_dirigirdatos.php?codper="+codper;
	}
function EnviarEPP(){
	var dni = document.form1.dni.value;
	var codepp = document.form1.var_epp.value;
	window.location="cvp_dirigirEpp.php?dni="+dni+"&codepp="+codepp;
	}
function TipoEnt(){
	var codTEn = parseInt(document.form1.var_TENT.value); 
    document.form1.tent.value=codTEn;
       }
function ActualizarPers(){
  var dni = document.form1.dni.value; 
  if (dni!=""){window.location = "cvp_personal_ver.php?dociden_per="+dni+"&tipo=todos&pagina=1&param=1";} else{alert('No Eligio Un Personal!!!'); document.form1.var_persona.focus(); return; }
    }
function NuevoEquipo(){
	var dni = document.form1.dni.value;
	var codepp = document.form1.codepp.value;
	var foto = document.form1.foto.value;
	var nombre = document.form1.nombre.value;
	var empresa = document.form1.empresa.value;
	var cargo = document.form1.cargo.value;
	var estado = document.form1.estado.value;
	window.location="cvp_nuevo_equipo.php?dni="+dni+"&codepp="+codepp+"&foto="+foto+"&nombre="+nombre+"&empresa="+empresa+"&cargo="+cargo+"&estado="+estado;
	}
function NuevoTipoEnt(){
	var dni = document.form1.dni.value;
	var codepp = document.form1.codepp.value;
	var foto = document.form1.foto.value;
	var nombre = document.form1.nombre.value;
	var empresa = document.form1.empresa.value;
	var cargo = document.form1.cargo.value;
	var estado = document.form1.estado.value;
	var duracion = document.form1.duracion.value;
	var cant = document.form1.cant.value;
	var umedi = document.form1.unidad.value;
	window.location="cvp_tipo_entrega.php?dni="+dni+"&codepp="+codepp+"&foto="+foto+"&nombre="+nombre+"&empresa="+empresa+"&cargo="+cargo+"&estado="+estado+"&duracion="+duracion+"&cant="+cant+"&umedi="+umedi;
	}
	
	function NuevoRespoLog(){
	var dni = document.form1.dni.value;
	var codepp = document.form1.codepp.value;
	var foto = document.form1.foto.value;
	var nombre = document.form1.nombre.value;
	var empresa = document.form1.empresa.value;
	var cargo = document.form1.cargo.value;
	var estado = document.form1.estado.value;
	var duracion = document.form1.duracion.value;
	var cant = document.form1.cant.value;
	var umedi = document.form1.unidad.value;
	var lugar = document.form1.var_lug.value;
	var TEntrega = document.form1.var_TENT.value;
	window.location="cvp_nuevo_responsable_log.php?dni="+dni+"&codepp="+codepp+"&foto="+foto+"&nombre="+nombre+"&empresa="+empresa+"&cargo="+cargo+"&estado="+estado+"&duracion="+duracion+"&cant="+cant+"&umedi="+umedi+"&lugar="+lugar+"&TEntrega="+TEntrega;
	}
function EniviarGrabarEntregaEPP(){
     var Pers = document.form1.var_persona;
	 var eq = document.form1.var_epp;
	 var cant= document.form1.cant;
	 var tent = document.form1.var_TENT;
     var lug = document.form1.var_lug;
	 var persRes = document.form1.var_perslog;
	 if (Pers.value=='0'){alert('No Eligio Un personal!!');Pers.focus();}
	 else{
	 		if(eq.value=='0'){alert('No Eligio Un Equipo Epp!!');eq.focus();}
			else{
			    if(isNaN(cant.value)||cant.value=="" ||cant.value==0){alert('La Cantidad no es Valor Aceptado!!');cant.focus();}
				else{
				   if(tent.value=='0'){alert('No Eligio Un Tipo de Entrega!!');tent.focus();}
				   else{
				     if(lug.value=='0'){alert('No Eligio Ningun Lugar de Entrega!!');lug.focus();}
					 else{
					      if(persRes.value=='0'){alert('No Eligio Ninguna Persona Responsable de Entrega!!');persRes.focus();}
					     else{
						   document.form1.submit();
						 }
					 }
				   }
				}
			}
	 	}
	 }
function mensaje(m){
  if (m==1){alert('Se Ingreso una Entrega de Epp Correctamente!!');}
    }
	
function actualizarCad(){
 num = parseInt(form1.Dura.value);
 milisegundos=parseInt(num*24*60*60*1000);
 f=form1.fechaEnt.value;
 f=f.split('/');
 //fecha=new Date();
 dia=f[0];
 mes=f[1];
 anio=f[2];
  
 fecha = new Date(anio,mes,dia);

 tiempo=fecha.getTime();
 total=fecha.setTime(parseInt(tiempo+milisegundos));
 dia=fecha.getDate();
 mes=fecha.getMonth();
 anio=fecha.getYear();
 dia = new String(dia);
 mes = new String(mes);
  if (dia.length == 1) {dia='0'+dia;}
  if (mes.length == 1) {mes='0'+mes;}
 document.form1.fechaDura.value=dia+"/"+mes+"/"+anio;
 }

</script>
<style type="text/css">
<!--
.Estilo1 {color: #FFFFFF}
-->
</style>
</head>
<?php if (isset($param)){?>
<body background="../imagenes/fondo.jpg" onLoad="mensaje(1)">
<?php }else{?>
<body background="../imagenes/fondo.jpg">
<?php }?>
<table width="650" border="0" cellspacing="0" cellpadding="0">
  <tr bgcolor="<?=$c_fondo_tr["fondo tr"]?>">
    <td width="25"><img src="../estilo_tabla/parte_sup_izq.gif" width="25" height="25"></td>
    <td width="680" background="../estilo_tabla/parte_sup_cen.gif" valign="bottom" >
      <div align="left" class="lblTitulo" ><span class="lblTituloReporte"> Control de EPP</span></div></td>
    <td width="25"><img src="../estilo_tabla/parte_sup_der.gif" width="25" height="25" border="0" usemap="#MapMap"></td>
  </tr>
  <tr>
    <td width="25" background="../estilo_tabla/parte_med_izq.gif">&nbsp;</td>
    <td width="420" height="86" background="../estilo_tabla/parte_med_cen.gif"><div align="center">
        <table width="518" border="0" cellspacing="0" cellpadding="0">
          <tr>
            <td width="518" height="15"><div align="center"></div></td>
          </tr>
		  <form name="form1" method="post" action="procesos/cvp_EntregaEpp_grabar.php">
          <tr>
            <td><div align="left">
                <table width="605" border="1" cellpadding="0" cellspacing="0" style="<?=$stylo['tabla']?>" bgcolor="<?=$c_fondo['fondo tabla']?>" bordercolor="<?=$bordetabla?>">
                  <tr valign="top" class="lblCampoBlanco">
                    <td  bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="Estilo1 lblForm"><div align="right">Persona</div></td>
                    <td width="7" class="lblForm">&nbsp;</td>
                    <td class="Estilo1 lblForm">
					 <?php echo $objPer->ListPersonal('var_persona',$dni)?>                      </td>
                  </tr>
                  <tr valign="top" class="lblCampoBlanco">
                    <td width="95"  bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="Estilo1 lblForm" ><div align="right">Equipo</div></td>
                    <td class="lblForm"><div align="center"></div></td>
                    <td width="493"><div align="center"></div>
                    <div align="left"><?php echo $objPer->ListEpp('var_epp',$codepp)?>                      <input type="button" name="Submit22222" value=".:Nuevo Equipo:." style="<?=$stylo['st2']?>" class="botira" onClick="NuevoEquipo();">
                      <input type="hidden" name="dni" value="<?=$dni?>">
					  <input type="hidden" name="duracion" value="<?=$duracion?>">
                      <input type="hidden" name="codepp" value="<?=$codepp?>">
</div></td>
                  </tr>
                  <tr valign="top" class="lblForm" >
                    <td bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="Estilo1 lblForm"><div align="right">Fecha de Entrega</div></td>
                    <td class="lblForm">&nbsp;</td>
                    <td class="lblForm" ><input name="fechaEnt" type="text" id="fechaEnt"  size="15" value="<?=date("d/m/Y")?>" onChange="Cambiar();">
                      <a onMouseOver="window.status='Calendario';return true;" onMouseOut="window.status='';return true;"  href="javascript:show_calendar('form1.fechaEnt');"><img src="../imagenes/calendar.jpg" alt="Calendario" width="16" height="15" border="0"></a>
                      Duraci&oacute;n
                      <input name="Dura" type="text" id="Dura" size="15" value="<?=$duracion." dias"?>" re>
                      Fecha Caducidad 
					  <?php if(isset($duracion)){$dura=extraerfechanormal(add_dia(date('Y-m-d'),$duracion));}?>
                      <input name="fechaDura" type="text" id="fechaDura" size="15" value="<?=$dura?>" readonly>
                      <input type="button" name="ac" value="AC" onClick="actualizarCad();"></td>
                  </tr>
                  <tr valign="top" class="lblForm" >
                    <td bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="Estilo1 lblForm"><div align="right">Cantidad</div></td>
                    <td class="lblForm">&nbsp;</td>
                    <td class="lblForm"><input name="cant" type="text" id="cant" size="5" value="<?php if(isset($cant)){echo $cant;}else{echo '1';}?>">
                      <input name="unidad" type="text" id="unidad" size="5" readonly value="<?=$umedi?>">
                    Tipo de Entrega 
                      <?php echo $objPer->ListTipoEntre('var_TENT',$TEntrega)?> <input type="button" name="Submit222222" value=".:Nuevo Tipo:." style="<?=$stylo['st2']?>" class="botira" onClick="NuevoTipoEnt();">
                      <input type="hidden" name="tent"></td>
                  </tr>
                  <tr valign="top" class="lblForm" >
                    <td bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="Estilo1 lblForm"><div align="right">Lugar de Entrega</div></td>
                    <td class="lblForm">&nbsp;</td>
                    <td class="lblForm"><?php echo $objPer->ListLugar('var_lug',$lugar)?>Responsable<?php echo $objPer->ListRespLogisti('var_perslog','valor_perslog')?> <input type="button" name="Submit22222232" value=".:Nuevo Resp.:." style="<?=$stylo['st2']?>" class="botira" onClick="NuevoRespoLog();"></td>
                  </tr>
                  <tr valign="top" class="lblForm" >
                    <td colspan="3" bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="Estilo1 lblForm"><div align="right">
                    </div></td>
                    </tr>
                  <tr valign="top" class="lblForm" >
                    <td bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="Estilo1 lblForm"><div align="right">Observaciones</div></td>
                    <td class="lblForm">&nbsp;</td>
                    <td class="lblForm"><textarea name="observ" cols="50" rows="2" id="observ"></textarea></td> 
             
                  </tr>

                  <? 
			?>
                </table>
            </div></td>
          </tr>
          <tr>
            <td><div align="left">
              <table width="605" border="0" style="<?=$stylo['tabla']?>" bgcolor="<?=$c_fondo['fondo tabla']?>" bordercolor="<?=$bordetabla?>">
                  <tr>
                    <td colspan="2" class="Estilo1 lblForm">&nbsp;</td>
                    <td colspan="3"><input type="hidden" name="foto" value="<?=$foto?>"></td>
                    <td width="125" rowspan="8"><table width="102" height="123" border="1" align="right">
                        <tr>
                          <td width="100" height="133"><img src="<?php $ruta ="../../../parametros/fotos_per/"; $foto=$foto; $fotodesc="desconocido.gif";
																     if(!file_exists($ruta.$foto)|| $foto==NULL){echo $ruta.$fotodesc;}
																	 else{ if(file_exists($ruta.$foto)){echo $ruta.$foto;}}					
										                             ?>" class="foto"></td>
                        </tr>
                    </table></td>
                  </tr>
                  <tr>
                  <td colspan="2" class="Estilo1 lblForm"><div align="right"></div></td>
                  <td colspan="3" >&nbsp;</td>
                  </tr>	
                <tr>
                  <td colspan="2" bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="Estilo1 lblForm"><div align="right">Persona</div></td>
                  <td colspan="3" class="rdoBanners">&nbsp;&nbsp;&nbsp;&nbsp;<?=$nombre?>&nbsp;
                    <input type="hidden" name="nombre" value="<?=$nombre?>"></td>
                  </tr>
                <tr>
                  <td colspan="2" bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="Estilo1 lblForm"><div align="right">Empresa</div></td>
                  <td colspan="3" class="rdoBanners">&nbsp;&nbsp;&nbsp;&nbsp;<?=$empresa?>
                    <input type="hidden" name="empresa" value="<?=$empresa?>"></td>
                  </tr>
                <tr>
                  <td colspan="2" bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="Estilo1 lblForm"><div align="right">Cargo</div></td>
                  <td width="184" class="rdoBanners">&nbsp;&nbsp;&nbsp;&nbsp;<?=$cargo?>
                    <input type="hidden" name="cargo" value="<?=$cargo?>"></td>
                  <td width="185" class="rdoBanners"><span class="lblForm">
                    <input type="button" name="Submit2222222" value=".:Actualizar Datos Del Personal:." style="<?=$stylo['st2']?>" class="botira" onClick="ActualizarPers();">
                  </span></td>
                  <td width="33" class="rdoBanners">&nbsp;</td>
                </tr>
                <tr>
                  <td colspan="2" bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="Estilo1 lblForm" ><div align="right">Estado</div></td>
                  <td colspan="3" class="rdoBanners">&nbsp;&nbsp;&nbsp;&nbsp;<?=$estado?>
                    <input type="hidden" name="estado" value="<?=$estado?>"></td>
                </tr>
                <tr>
                  <td colspan="2">&nbsp;</td>
                  <td colspan="3">&nbsp;</td>
                </tr>
                <tr>
                  <td width="15">&nbsp;</td>
                  <td width="35">&nbsp;</td>
                  <td colspan="3">&nbsp;</td>
                </tr>
              </table>
              <span class="lblForm"></span></div></td>
          </tr>
          <tr>
            <td><table width="605" border="0" style="<?=$stylo['tabla']?>" bgcolor="<?=$c_fondo['fondo tabla']?>" bordercolor="<?=$bordetabla?>">
              <tr>
                <td colspan="3" bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="lblForm Estilo1"><div align="center"><strong>File Personal (Historial)</strong></div></td>
                <td>&nbsp;</td>
              </tr>
              <tr>
                <td width="349" bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="Estilo1 lblForm"><div align="center">EPP</div></td>
                <td width="51" bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="Estilo1 lblForm"><div align="left">Cantidad</div></td>
                <td width="46" bgcolor="<?=$c_fondo_tr["fondo tr"]?>" class="Estilo1 lblForm">Unidad</td>
                <td width="141">&nbsp;</td>
              </tr>
			  <?php 
			  		 if(isset($dni)){
					 $rs = $objPer->DevolverCantDadaEPP($dni);
			  	     while($filaE=$objPer->NextRow($rs)){
			  ?>
              <tr>  
                <td align="right" class="rdoBanners"><?=$filaE['tipo_epp']?></td>
                <td align="center" class="rdoBanners"><?=$filaE['total']?></td>
                <td align="center" class="rdoBanners"><?=$filaE['umedida']?></td>
                <td>&nbsp;</td>
              </tr>
			  <?php }$objPer->Liberar($rs);}?>
            </table></td>
          </tr>
          <tr>
              <td>
                <div align="center">
                  <table width="415" border="0" cellspacing="0" cellpadding="0">
                    <tr>
                      <td width="155"><div align="right">
                          <input type="button" name="Submit22" value=".:Guardar:." style="<?=$stylo['st2']?>" class="botira" onClick="EniviarGrabarEntregaEPP();">
                      </div></td>
                      <td width="139">&nbsp;
                      </td>
                      <td width="121"><div align="left">
                          <input type="button" name="Submit2" value=".:Cancelar:." style="<?=$stylo['st2']?>" class="botira" onClick="volver();">
                      </div></td>
                    </tr>
                  </table>
              </div></td>
          </tr>
		  </form>
        </table>
    </div></td>
    <td background="../estilo_tabla/parte_med_der.gif">&nbsp;</td>
  </tr>
  <tr>
    <td><img src="../estilo_tabla/parte_inf_izq.gif" width="25" height="25"></td>
    <td height="25" background="../estilo_tabla/parte_inf_cen.gif">&nbsp;</td>
    <td><img src="../estilo_tabla/parte_inf_der.gif" width="25" height="25"></td>
  </tr>
</table>
`
<map name="MapMap">
  <area shape="rect" coords="2,5,22,21" href="fondo.php">
</map>
</body>
</html>

